@@ -84,9 +84,15 @@ class Worker:
                 if len(frames) == 3:
                     module = self.serving_methods[self.module_name]
                     serving_args = frames[len(frames) - 1].decode()
-                    serving_args_dict = json.loads(serving_args)
-
-                    frames[len(frames) - 1] = module[ModuleMethod](**serving_args_dict).encode()
+                    try:
+                        serving_args_dict = json.loads(serving_args)
+                    except Exception as e:
+                        # just in case if not json
+                        serving_args_dict = serving_args
+                    if type(serving_args_dict) is dict:
+                        frames[len(frames) - 1] = module[ModuleMethod](**serving_args_dict).encode()
+                    else:
+                        frames[len(frames) - 1] = module[ModuleMethod](serving_args_dict).encode()
                     self.logger.debug("I: Normal reply")
                     worker.send_multipart(frames)
                     liveness = HEARTBEAT_LIVENESS
